from os import path

import sass


class BeetleSass(object):
    def __init__(self, config):
        self.output_style = config.get('output_style', 'nested')

    def compile(self, content):
        return sass.compile(string=content, output_style=self.output_style)

    def render(self, content, suggested_path):
        content = self.compile(content.decode('utf-8'))

        file_path, _ = path.splitext(suggested_path)
        return '{}.css'.format(file_path), content.encode('utf-8')


def register(context, plugin_config):
    sass_extensions = ['sass', 'scss']
    beetle_sass = BeetleSass(plugin_config)
    context.content_renderer.add_renderer(sass_extensions, beetle_sass.compile)
    context.includer.add(sass_extensions, beetle_sass.render)



from setuptools import setup

setup(
    name='Beetle-Sass',
    version='1.2.0',
    author='Jeppe Toustrup',
    author_email='jeppe@tenzer.dk',
    description='Enables Beetle to handle Sass files',
    url='https://github.com/Tenzer/beetle-sass',
    license='MIT',
    packages=[
        'beetle_sass'
    ],
    install_requires=[
        'libsass',
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Text Processing :: Markup',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],
)
